@@ -94,18 +94,26 @@ class BaseTestGeocoder(ABC):
         pass
 
     async def geocode_run(
-        self, payload, expected, expect_failure=False,
+        self, payload, expected,
+        *,
+        skiptest_on_errors=True,
+        expect_failure=False,
         skiptest_on_failure=False
     ):
         """
         Calls geocoder.geocode(**payload), then checks against `expected`.
         """
         cls = type(self)
-        result = await self._make_request(self.geocoder, 'geocode', **payload)
+        result = await self._make_request(
+            self.geocoder, 'geocode',
+            skiptest_on_errors=skiptest_on_errors,
+            **payload,
+        )
+        if expect_failure:
+            assert result is None
+            return
         if result is None:
-            if expect_failure:
-                return
-            elif skiptest_on_failure:
+            if skiptest_on_failure:
                 pytest.skip('%s: Skipping test due to empty result' % cls.__name__)
             else:
                 pytest.fail('%s: No result found' % cls.__name__)
@@ -116,18 +124,26 @@ class BaseTestGeocoder(ABC):
         return result
 
     async def reverse_run(
-        self, payload, expected, expect_failure=False,
+        self, payload, expected,
+        *,
+        skiptest_on_errors=True,
+        expect_failure=False,
         skiptest_on_failure=False
     ):
         """
         Calls geocoder.reverse(**payload), then checks against `expected`.
         """
         cls = type(self)
-        result = await self._make_request(self.geocoder, 'reverse', **payload)
+        result = await self._make_request(
+            self.geocoder, 'reverse',
+            skiptest_on_errors=skiptest_on_errors,
+            **payload,
+        )
+        if expect_failure:
+            assert result is None
+            return
         if result is None:
-            if expect_failure:
-                return
-            elif skiptest_on_failure:
+            if skiptest_on_failure:
                 pytest.skip('%s: Skipping test due to empty result' % cls.__name__)
             else:
                 pytest.fail('%s: No result found' % cls.__name__)
@@ -137,9 +153,12 @@ class BaseTestGeocoder(ABC):
                              **expected)
         return result
 
-    async def reverse_timezone_run(self, payload, expected):
+    async def reverse_timezone_run(self, payload, expected, *, skiptest_on_errors=True):
         timezone = await self._make_request(
-            self.geocoder, 'reverse_timezone', **payload)
+            self.geocoder, 'reverse_timezone',
+            skiptest_on_errors=skiptest_on_errors,
+            **payload,
+        )
         if expected is None:
             assert timezone is None
         else:
@@ -147,20 +166,32 @@ class BaseTestGeocoder(ABC):
 
         return timezone
 
-    async def _make_request(self, geocoder, method, *args, **kwargs):
+    async def _make_request(self, geocoder, method, *, skiptest_on_errors, **kwargs):
         cls = type(self)
         call = getattr(geocoder, method)
         run_async = isinstance(geocoder.adapter, BaseAsyncAdapter)
         try:
             if run_async:
-                result = await call(*args, **kwargs)
+                result = await call(**kwargs)
             else:
-                result = call(*args, **kwargs)
+                result = call(**kwargs)
+        except exc.GeocoderRateLimited as e:
+            if not skiptest_on_errors:
+                raise
+            pytest.skip(
+                "%s: Rate-limited, retry-after %s" % (cls.__name__, e.retry_after)
+            )
         except exc.GeocoderQuotaExceeded:
+            if not skiptest_on_errors:
+                raise
             pytest.skip("%s: Quota exceeded" % cls.__name__)
         except exc.GeocoderTimedOut:
+            if not skiptest_on_errors:
+                raise
             pytest.skip("%s: Service timed out" % cls.__name__)
         except exc.GeocoderUnavailable:
+            if not skiptest_on_errors:
+                raise
             pytest.skip("%s: Service unavailable" % cls.__name__)
         return result
 
